#
# spec file for package gnuchess
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnuchess
Version:        6.2.9
Release:        2.12
Summary:        GNU Chess Program
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Chess
URL:            https://www.gnu.org/software/chess/
Source0:        https://ftp.gnu.org/gnu/chess/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/chess/%{name}-%{version}.tar.gz.sig
# WARNING: Don't forget to re-generate book.dat manually before submit!
# Simply remove the source and build, updated book will be generated.
Source2:        book_1.02.pgn.bz2
Source3:        genbook.sh
Source4:        xgnuchess
Source5:        http://savannah.gnu.org/project/memberlist-gpgkeys.php?group=chess&download=1#/gnuchess.keyring
BuildRequires:  expect
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  help2man
BuildRequires:  readline-devel
%if 0%{?suse_version} && 0%{?suse_version} < 1550
Requires(post): info
Requires(preun):info
%endif
Suggests:       xboard
Provides:       chess_backend
Provides:       gchess

%description
A worthy chess opponent that runs in text mode. Find an X11 interface
in the xboard package.

%prep
%autosetup -p1

%build
%configure
%make_build
sed -i 's/^Book[[:space:]]*=[[:space:]]*false/Book = true/;s/^OwnBook[[:space:]]=[[:space:]]*false/OwnBook = true/' src/gnuchess.ini
sh %{SOURCE3} %{SOURCE2}

%install
%make_install
# install xgnuchess
install -m 755 %{SOURCE4} %{buildroot}/%{_bindir}
%find_lang %{name}

%if 0%{?suse_version} && 0%{?suse_version} < 1550
%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%endif

%files -f %{name}.lang
%doc AUTHORS ChangeLog NEWS README TODO
%license COPYING
%{_bindir}/*
%{_mandir}/man*/*
%{_infodir}/gnuchess.info%{?ext_info}
%{_datadir}/gnuchess
%dir %{_datadir}/games/plugins
%dir %{_datadir}/games/plugins/logos
%{_datadir}/games/plugins/logos/%{name}.png
%dir %{_datadir}/games/plugins/xboard
%{_datadir}/games/plugins/xboard/%{name}.eng

%changelog
* Fri Feb 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Only require info and call its macros on suse_version < 1550:
  in Tumbleweed, info handles its file via file triggers since Sep
  2019.
* Sat Jul 31 2021 Dirk Müller <dmueller@suse.com>
- update to 6.2.9:
  - Fixed potential buffer overflow in pgnload and pgnreplay (CVE-2021-30184)
- drop txtJ07eHdR0m6.patch (upstream)
* Fri May 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 6.2.8
  * Bug fixes in the input/output processing
* Thu Apr  8 2021 Matej Cepl <mcepl@suse.com>
- Add txtJ07eHdR0m6.patch to fix CVE-2021-30184 (reported upstream on
  https://lists.gnu.org/archive/html/bug-gnu-chess/2021-04/msg00000.html )
  (boo#1184531)
* Sun May 31 2020 Andreas Stieger <andreas.stieger@gmx.de>
- gnuchess 6.2.7:
  * minor bug fixes in the build system
* Sun Apr 19 2020 Matej Cepl <mcepl@suse.com>
- Update to the version 6.2.6:
  - Fix buffer overflow on load EPD file (bsc#1148736 CVE-2019-15767).
  - Fix move validation when cleaning up moves, e.g. accepting
    '0-0' for O-O'.
  - More consistent use of period in translatable texts.
  - Minor fixes on compilation warnings
  - New and updated translations.
* Sat Apr 28 2018 antoine.belvire@opensuse.org
- Only suggest xboard, don't recommend it.
- Use %%license instead of %%doc for license file (boo#1082318).
- Use %%install_info_delete macro instead of rewriting it.
* Tue Jul 25 2017 astieger@suse.com
- gnuchess 6.2.5:
  * Command history based on readline.
  * New commands: coords/nocoords to enable/disable coordinates
    when printing the board.
  * Command pgnsave will prompt the user to overwrite or not an existing
    file instead of appending the current game to the file.
  * New languages.
  * Bug fixes.
* Tue Nov 15 2016 astieger@suse.com
- gnuchess 6.2.4:
  * Print error for invalid move.
  * Truncate user input if longer than 128 characters
    fixing CVE-2015-8972: user input buffer overflow (boo#1010143)
* Fri Oct 28 2016 astieger@suse.com
- gnuchess 6.2.3:
  * Quit after compiling book with option -a (--addbook)
  * Updated translations
* Mon Oct 19 2015 astieger@suse.com
- gnuchess 6.2.2:
  * More robust program exit concerning threads.
  * Detailed error messages for bad FEN syntax.
* Sun Jan 18 2015 andreas.stieger@gmx.de
- gnuchess 6.2.1:
  - Man page in English.
- includes changes from 6.2.0;
  - "Tighter connection" with XBoard by means of an engine file and
    a logo, as expected by XBoard (>= 4.6.0).
  - Uppercase chars only for piece names, as Fruit doesn't like
  lowercase.
  - A man page based on help2man.
- verify source signature
* Sun Oct  5 2014 andreas.stieger@gmx.de
- gnuchess 6.1.2:
  * CFLAGS replaced by CPPFLAGS in info.
  * Fix for correct handling of castling moves.
  * Include translations to other languages.
- includes changes from 6.1.1:
  * Include translations to other languages.
  * Minor corrections in translatable strings.
  * Migrate frontend to C++.
  * Use autoconf 2.69 and require it in configure.ac.
  * Use automake 1.14.
- includes changes from 6.1.0:
  * Add support for package internationalization based on gettext
  * Include first translations provided by the Translation Team.
  * Graphic mode, a new board shape based on the unicode characters
    for chess.
  * pgnreplay command, similar to pgnload, with the capability of
    manually showing a saved game step by step and moving backwards
  * Fix bug in setboard.
  * Avoid using 100%% CPU in UCI mode.
  * Rename the small book.bin as smallbook.bin.
- includes changes from 6.0.3:
  * Update to autoconf 2.69, automake 1.13
  * If in manual mode, keep it after undo.
  * Remove some unused code.
  * Avoid crashing when importing book_1.01.pgn
- licence is GPL-3.0+
* Fri Oct 26 2012 lars@linux-schulserver.de
- update gnuchess to 6.0.2:
  + New option --addbook to compile a book.
  + Maximum file name length of EPD files extended to 127 characters.
  + Book file allowed to be read only unless the BookLearn
    option is set.
- new upstream Url
- removed upstreamed gnuchess-return-nonvoid.patch
- recommend xboard
* Tue Nov 29 2011 jreidinger@suse.com
- update gnuchess to official version 6.0.1
- clean up patches
- change generation of recent book dat from source during build
* Wed Aug  4 2010 packman@links2linux.de
- updated gnuchess to (unofficial) version 5.07.94.1b
- updated to most recent book.dat
- removed obsolete getline patch
- added patches to fix a few rpmlint-warnings/errors
- added gnuchess-add_new_bookpath.diff so gnuchess finds the default
  opening book in /usr/share/gnuchess
* Mon Jan 11 2010 packman@links2linux.de
- updated to (unofficial) version 5.07.9b by M. Vandenbergh
- added script "xgnuchess" to start xboard with gnuchess
  as first and second chess engine
- patches refreshed
- description updated
* Fri Oct 16 2009 marek.belisko@open-nandra.com
- Add missing fclose() and correct typo (bnc#534576)
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid conflict with function
  from glibc
* Thu Nov  6 2008 ro@suse.de
- remove NoSource tag
* Fri Mar 30 2007 ro@suse.de
- added flex,bison to buildreq
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Apr  5 2005 mmj@suse.de
- Make gcc4 happy
* Thu Aug 26 2004 sbrabec@suse.cz
- Updated to version 5.07.
- Updated book to version 1.01.
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Aug  7 2003 sbrabec@suse.cz
- Updated to version 5.06.
* Tue Feb 11 2003 sbrabec@suse.cz
- Updated to version 5.05.
- Adapt to new gnuchess packaging scheme.
- Added new build script genbook.sh to shrink source RPM.
* Tue Feb  4 2003 sbrabec@suse.cz
- Provide chess_backend.
* Mon Aug  6 2001 dan@suse.cz
- update to 5.02 version
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Tue May  2 2000 vinil@suse.cz
- prefix problem fixed
* Tue Apr 11 2000 vinil@suse.cz
- buildroot added
* Thu Jan 20 2000 ro@suse.de
- man to /usr/share/man
* Tue Oct 12 1999 ro@suse.de
- update to pl80
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
